==> senscritique-0.2.tar.gz: senscritique-0.2/README.md <==
# SensCritique Takeout

[![PyPI status][PyPI image]][PyPI] [![Build status][Build image]][Build] [![Updates][Dependency image]][PyUp] [![Python 3][Python3 image]][PyUp] [![Code coverage][Coveralls image]][Coveralls] [![Code coverage BIS][Codecov image]][Codecov]

  [PyPI]: https://pypi.python.org/pypi/senscritique
  [PyPI image]: https://badge.fury.io/py/senscritique.svg

  [Build]: https://travis-ci.org/woctezuma/SensCritique-Takeout
  [Build image]: https://travis-ci.org/woctezuma/SensCritique-Takeout.svg?branch=master

  [PyUp]: https://pyup.io/repos/github/woctezuma/SensCritique-Takeout/
  [Dependency image]: https://pyup.io/repos/github/woctezuma/SensCritique-Takeout/shield.svg
  [Python3 image]: https://pyup.io/repos/github/woctezuma/SensCritique-Takeout/python-3-shield.svg

  [Coveralls]: https://coveralls.io/github/woctezuma/SensCritique-Takeout?branch=master
  [Coveralls image]: https://coveralls.io/repos/github/woctezuma/SensCritique-Takeout/badge.svg?branch=master

  [Codecov]: https://codecov.io/gh/woctezuma/SensCritique-Takeout
  [Codecov image]: https://codecov.io/gh/woctezuma/SensCritique-Takeout/branch/master/graph/badge.svg

This repository contains Python code to export your data from [SensCritique.com](https://www.senscritique.com).

## Installation

The code is packaged for [PyPI](https://pypi.org/project/senscritique/), so that the installation consists in running:

```bash
pip install senscritique
```

## Usage

Collections can be downloaded as follows:

```python
import senscritique

# Download in JSON format the collection of the given user
data = senscritique.parse_and_cache(user_name='wok', data_type='collection')
```

Soon: reviews and lists.

## References

- [Google Takeout](https://en.wikipedia.org/wiki/Google_Takeout)

==> senscritique-0.4.tar.gz: senscritique-0.4/README.md <==
# SensCritique Takeout

[![PyPI status][PyPI image]][PyPI] [![Build status][Build image]][Build] [![Updates][Dependency image]][PyUp] [![Python 3][Python3 image]][PyUp] [![Code coverage][Coveralls image]][Coveralls] [![Code coverage BIS][Codecov image]][Codecov]

  [PyPI]: https://pypi.python.org/pypi/senscritique
  [PyPI image]: https://badge.fury.io/py/senscritique.svg

  [Build]: https://travis-ci.org/woctezuma/SensCritique-Takeout
  [Build image]: https://travis-ci.org/woctezuma/SensCritique-Takeout.svg?branch=master

  [PyUp]: https://pyup.io/repos/github/woctezuma/SensCritique-Takeout/
  [Dependency image]: https://pyup.io/repos/github/woctezuma/SensCritique-Takeout/shield.svg
  [Python3 image]: https://pyup.io/repos/github/woctezuma/SensCritique-Takeout/python-3-shield.svg

  [Coveralls]: https://coveralls.io/github/woctezuma/SensCritique-Takeout?branch=master
  [Coveralls image]: https://coveralls.io/repos/github/woctezuma/SensCritique-Takeout/badge.svg?branch=master

  [Codecov]: https://codecov.io/gh/woctezuma/SensCritique-Takeout
  [Codecov image]: https://codecov.io/gh/woctezuma/SensCritique-Takeout/branch/master/graph/badge.svg

This repository contains Python code to export your data from [SensCritique.com](https://www.senscritique.com).

## Installation

The code is packaged for [PyPI](https://pypi.org/project/senscritique/), so that the installation consists in running:

```bash
pip install senscritique
```

## Usage

### Library (« collection »)

Libraries can be downloaded as follows:

```python
import senscritique

# Download in JSON format the collection of the given user
data = senscritique.parse_and_cache(user_name='wok', data_type='collection')
```

### Reviews (« critiques »)

Reviews can be downloaded as follows:

```python
import senscritique

# Download in JSON format the collection of the given user
data = senscritique.parse_and_cache(user_name='wok', data_type='critiques')
```

### Rankings (« listes »)

Rankings can be downloaded as follows:

```python
import senscritique

# Download in JSON format the collection of the given user
data = senscritique.parse_and_cache(user_name='wok', data_type='listes')
```

## References

- [Google Takeout](https://en.wikipedia.org/wiki/Google_Takeout)
